@@ -19,6 +19,7 @@ __all__ = [
     'Symbol',
     'SedBase',
     'SedIdGroupMixin',
+    'TargetGroupMixin',
     'SedDocument',
     'Simulation',
     'SteadyStateSimulation',
@@ -48,6 +49,7 @@ __all__ = [
     'Output',
     'Report',
     'DataSet',
+    'Plot',
     'Plot2D',
     'Plot3D',
     'AxisScale',
@@ -60,27 +62,63 @@ class ModelLanguage(str, enum.Enum):
     """ Model language """
     BNGL = 'urn:sedml:language:bngl'
     CellML = 'urn:sedml:language:cellml'
+    CopasiML = 'urn:sedml:language:copasiml'
+    GINML = 'urn:sedml:language:ginml'
+    HOC = 'urn:sedml:language:hoc'
+    Kappa = 'urn:sedml:language:kappa'
+    LEMS = 'urn:sedml:language:lems'
+    MASS = 'urn:sedml:language:mass'
+    MorpheusML = 'urn:sedml:language:morpheusml'
     NeuroML = 'urn:sedml:language:neuroml'
+    pharmML = 'urn:sedml:language:pharmml'
+    RBA = 'urn:sedml:language:rba'
     SBML = 'urn:sedml:language:sbml'
+    Smoldyn = 'urn:sedml:language:smoldyn'
     VCML = 'urn:sedml:language:vcml'
+    XPP = 'urn:sedml:language:xpp'
+    ZGINML = 'urn:sedml:language:zginml'
 
 
 class ModelLanguagePattern(str, enum.Enum):
     """ Model language """
-    BNGL = 'urn:sedml:language:bngl'
+    BNGL = r'^urn:sedml:language:bngl(\.|$)'
     CellML = r'^urn:sedml:language:cellml(\.\d+_\d+)?$'
-    NeuroML = r'urn:sedml:language:neuroml(\.version-\d+_\d+_\d+\.level\-\d+)?$'
+    CopasiML = r'^urn:sedml:language:copasiml(\.|$)'
+    GINML = r'^urn:sedml:language:ginml(\.|$)'
+    HOC = r'^urn:sedml:language:hoc(\.|$)'
+    Kappa = r'^urn:sedml:language:kappa(\.|$)'
+    LEMS = r'^urn:sedml:language:lems(\.|$)'
+    MASS = r'^urn:sedml:language:mass(\.|$)'
+    MorpheusML = r'^urn:sedml:language:morpheusml(\.|$)'
+    NeuroML = r'^urn:sedml:language:neuroml(\.version-\d+_\d+_\d+\.level\-\d+)?$'
+    pharmML = r'^urn:sedml:language:pharmml(\.|$)'
+    RBA = r'^urn:sedml:language:rba(\.|$)'
     SBML = r'^urn:sedml:language:sbml(\.level\-\d+\.version\-\d+)?$'
-    VCML = 'urn:sedml:language:vcml'
+    Smoldyn = r'^urn:sedml:language:smoldyn(\.|$)'
+    VCML = r'^urn:sedml:language:vcml(\.|$)'
+    XPP = r'^urn:sedml:language:xpp(\.|$)'
+    ZGINML = r'^urn:sedml:language:zginml(\.|$)'
 
 
 class ModelLanguageEdamId(str, enum.Enum):
     """ Model language EDAM id """
     BNGL = 'format_3972'
     CellML = 'format_3240'
+    CopasiML = 'format_9003'
+    GINML = 'format_9009'
+    HOC = 'format_9005'
+    Kappa = 'format_9006'
+    LEMS = 'format_9004'
+    MASS = 'format_9011'
+    MorpheusML = 'format_9002'
     NeuroML = 'format_3971'
+    pharmML = 'format_9007'
+    RBA = 'format_9012'
     SBML = 'format_2585'
-    VCML = None
+    Smoldyn = 'format_9001'
+    VCML = 'format_9000'
+    XPP = 'format_9010'
+    ZGINML = 'format_9008'
 
 
 class Symbol(str, enum.Enum):
@@ -103,7 +141,7 @@ class SedBase(abc.ABC):
         """ Determine if simulations are equal
 
         Args:
-            other (:obj:`Simulation`): another content item
+            other (:obj:`SedBase`): another content item
 
         Returns:
             :obj:`bool`: :obj:`True`, if two simulations are equal
@@ -132,7 +170,7 @@ class SedIdGroupMixin(abc.ABC):
         """ Determine if simulations are equal
 
         Args:
-            other (:obj:`Simulation`): another content item
+            other (:obj:`SedIdGroupMixin`): another content item
 
         Returns:
             :obj:`bool`: :obj:`True`, if two simulations are equal
@@ -142,6 +180,37 @@ class SedIdGroupMixin(abc.ABC):
             and self.name == other.name
 
 
+class TargetGroupMixin(abc.ABC):
+    """ Object with an id and optional name
+
+    Attributes:
+        target (:obj:`str`): id
+        target_namespaces (:obj:`dict`): map of prefixes of namespaces for the target to their URIs
+    """
+
+    def __init__(self, target=None, target_namespaces=None):
+        """
+        Args:
+            target (:obj:`str`): id
+            target_namespaces (:obj:`dict`): map of prefixes of namespaces for the target to their URIs
+        """
+        self.target = target
+        self.target_namespaces = target_namespaces or {}
+
+    def is_equal(self, other):
+        """ Determine if simulations are equal
+
+        Args:
+            other (:obj:`TargetGroupMixin`): another content item
+
+        Returns:
+            :obj:`bool`: :obj:`True`, if two simulations are equal
+        """
+        return self.__class__ == other.__class__ \
+            and self.target == other.target \
+            and self.target_namespaces == other.target_namespaces
+
+
 class SedDocument(SedBase):
     """ A SED-ML document
 
@@ -199,7 +268,7 @@ class SedDocument(SedBase):
         """ Determine if SED-ML documents are equal
 
         Args:
-            other (:obj:`Simulation`): another SED-ML document
+            other (:obj:`SedDocument`): another SED-ML document
 
         Returns:
             :obj:`bool`: :obj:`True`, if two SED-ML documents are equal
@@ -512,7 +581,7 @@ class Model(SedBase, SedIdGroupMixin):
             and are_lists_equal(self.changes, other.changes)
 
 
-class ModelChange(SedBase, SedIdGroupMixin):
+class ModelChange(SedBase, SedIdGroupMixin, TargetGroupMixin):
     """ A change to a model
 
     Attributes:
@@ -532,8 +601,7 @@ class ModelChange(SedBase, SedIdGroupMixin):
         """
         SedBase.__init__(self)
         SedIdGroupMixin.__init__(self, id=id, name=name)
-        self.target = target
-        self.target_namespaces = target_namespaces or {}
+        TargetGroupMixin.__init__(self, target=target, target_namespaces=target_namespaces)
 
     def is_equal(self, other):
         """ Determine if model changes are equal
@@ -546,8 +614,7 @@ class ModelChange(SedBase, SedIdGroupMixin):
         """
         return SedBase.is_equal(self, other) \
             and SedIdGroupMixin.is_equal(self, other) \
-            and self.target == other.target \
-            and self.target_namespaces == other.target_namespaces
+            and TargetGroupMixin.is_equal(self, other)
 
 
 class ModelAttributeChange(ModelChange):
@@ -725,7 +792,7 @@ class Calculation(SedBase):
         """ Determine if model changes are equal
 
         Args:
-            other (:obj:`ComputeModelChange`): another content item
+            other (:obj:`Calculation`): another content item
 
         Returns:
             :obj:`bool`: :obj:`True`, if two model changes are equal
@@ -1030,7 +1097,7 @@ class SubTask(SedBase):
         """ Determine if repeated tasks are equal
 
         Args:
-            other (:obj:`RepeatedTask`): another content item
+            other (:obj:`SubTask`): another content item
 
         Returns:
             :obj:`bool`: :obj:`True`, if two repeated tasks are equal
@@ -1307,8 +1374,7 @@ class Variable(SedBase, SedIdGroupMixin):
         """
         SedBase.__init__(self)
         SedIdGroupMixin.__init__(self, id=id, name=name)
-        self.target = target
-        self.target_namespaces = target_namespaces or {}
+        TargetGroupMixin.__init__(self, target=target, target_namespaces=target_namespaces)
         self.symbol = symbol
         self.task = task
         self.model = model
@@ -1334,8 +1400,7 @@ class Variable(SedBase, SedIdGroupMixin):
         """
         return SedBase.is_equal(self, other) \
             and SedIdGroupMixin.is_equal(self, other) \
-            and self.target == other.target \
-            and self.target_namespaces == other.target_namespaces \
+            and TargetGroupMixin.is_equal(self, other) \
             and self.symbol == other.symbol \
             and ((self.task is None and self.task == other.task)
                  or (self.task is not None and other.task is not None and self.task.id == other.task.id)) \
@@ -1506,7 +1571,17 @@ class DataSet(SedBase, SedIdGroupMixin):
                      and self.data_generator.id == other.data_generator.id))
 
 
-class Plot2D(Output):
+class Plot(Output):
+    """ A 2D plot
+
+    Attributes:
+        id (:obj:`str`): id
+        name (:obj:`str`): name
+    """
+    pass  # pragma: no cover
+
+
+class Plot2D(Plot):
     """ A 2D plot
 
     Attributes:
@@ -1550,7 +1625,7 @@ class Plot2D(Output):
             and are_lists_equal(self.curves, other.curves)
 
 
-class Plot3D(Output):
+class Plot3D(Plot):
     """ A 3D plot
 
     Attributes:
