@@ -14,7 +14,8 @@ from ..xml.utils import eval_xpath
 from .data_model import (SedBase, SedIdGroupMixin, SedDocument,  # noqa: F401
                          Model, ModelLanguagePattern, ModelChange, ModelAttributeChange, AddElementModelChange,
                          ReplaceElementModelChange, RemoveElementModelChange, ComputeModelChange, SetValueComputeModelChange,
-                         Task, RepeatedTask, Output, Report, Plot2D, Plot3D,
+                         OneStepSimulation, SteadyStateSimulation, UniformTimeCourseSimulation,
+                         Task, RepeatedTask, Output, Report, Plot, Plot2D, Plot3D,
                          DataGenerator, Variable,
                          Range, UniformRange, VectorRange, FunctionalRange, UniformRangeType)
 from .math import AGGREGATE_MATH_FUNCTIONS, compile_math, eval_math
@@ -58,6 +59,8 @@ __all__ = [
     'get_namespaces_for_sed_object',
     'get_xml_node_namespace_tag_target',
     'is_model_language_encoded_in_xml',
+    'does_model_language_use_xpath_variable_targets',
+    'get_task_results_shape',
 ]
 
 
@@ -386,7 +389,7 @@ def resolve_model(model, sed_doc, working_dir):
         return None
 
 
-def apply_changes_to_xml_model(model, model_etree, sed_doc, working_dir,
+def apply_changes_to_xml_model(model, model_etree, sed_doc=None, working_dir=None,
                                variable_values=None, range_values=None,
                                validate_unique_xml_targets=True):
     """ Modify an XML-encoded model according to a model change
@@ -394,8 +397,10 @@ def apply_changes_to_xml_model(model, model_etree, sed_doc, working_dir,
     Args:
         model (:obj:`Model`): model
         model_etree (:obj:`etree._ElementTree`): element tree for model
-        sed_doc (:obj:`SedDocument`): parent SED document; used to resolve sources defined by reference to other models
-        working_dir (:obj:`str`): working directory of the SED document (path relative to which models are located)
+        sed_doc (:obj:`SedDocument`, optional): parent SED document; used to resolve sources defined by reference to other models;
+            required for compute changes
+        working_dir (:obj:`str`, optional): working directory of the SED document (path relative to which models are located);
+            required for compute changes
         variable_values (:obj:`dict`, optional): dictionary which contains the value of each variable of each
             compute model change
         range_values (:obj:`dict`, optional): dictionary which contains the value of each range of each
@@ -860,7 +865,7 @@ def remove_plots(sed_doc):
         sed_doc (:obj:`SedDocument`): SED document
     """
     for output in list(sed_doc.outputs):
-        if isinstance(output, (Plot2D, Plot3D)):
+        if isinstance(output, Plot):
             sed_doc.outputs.remove(output)
 
 
@@ -897,23 +902,30 @@ def get_models_referenced_by_task(task):
         :obj:`set` of :obj:`Model`: models
     """
     if isinstance(task, Task):
-        return set([task.model])
+        if task.model:
+            return set([task.model])
+        else:
+            return set()
 
     elif isinstance(task, RepeatedTask):
         models = set()
 
-        models.update(get_models_referenced_by_range(task.range))
+        if task.range:
+            models.update(get_models_referenced_by_range(task.range))
 
         for change in task.changes:
-            models.update(get_models_referenced_by_model_change(change))
+            if change:
+                models.update(get_models_referenced_by_model_change(change))
 
         for sub_task in task.sub_tasks:
-            models.update(get_models_referenced_by_task(sub_task.task))
+            if sub_task and sub_task.task:
+                models.update(get_models_referenced_by_task(sub_task.task))
 
         if task.range:
             models.update(get_models_referenced_by_range(task.range))
         for range in task.ranges:
-            models.update(get_models_referenced_by_range(range))
+            if range:
+                models.update(get_models_referenced_by_range(range))
 
         return models
 
@@ -1124,6 +1136,29 @@ def get_xml_node_namespace_tag_target(etree, target_namespaces=None):
 def is_model_language_encoded_in_xml(language):
     """ Determine if the model language is encoded in XML
 
+    Args:
+        language (:obj:`str`): language
+
+    Returns:
+        :obj:`bool`: :obj:`True`, if the model language is encoded in XML
+    """
+    return (
+        language and (
+            re.match(ModelLanguagePattern.CellML, language)
+            or re.match(ModelLanguagePattern.CopasiML, language)
+            or re.match(ModelLanguagePattern.GINML, language)
+            or re.match(ModelLanguagePattern.LEMS, language)
+            or re.match(ModelLanguagePattern.MorpheusML, language)
+            or re.match(ModelLanguagePattern.NeuroML, language)
+            or re.match(ModelLanguagePattern.SBML, language)
+            or re.match(ModelLanguagePattern.VCML, language)
+        )
+    )
+
+
+def does_model_language_use_xpath_variable_targets(language):
+    """ Determine if the model language uses XPaths to target variables of data generators
+
     Args:
         language (:obj:`str`): language
 
@@ -1132,7 +1167,8 @@ def is_model_language_encoded_in_xml(language):
     """
     return (
         re.match(ModelLanguagePattern.CellML, language)
-        or re.match(ModelLanguagePattern.NeuroML, language)
+        or re.match(ModelLanguagePattern.CopasiML, language)
+        or re.match(ModelLanguagePattern.MorpheusML, language)
         or re.match(ModelLanguagePattern.SBML, language)
         or re.match(ModelLanguagePattern.VCML, language)
     )
@@ -1167,3 +1203,37 @@ def get_all_sed_objects(doc, type=(SedBase, SedIdGroupMixin)):
 
     # filter out elements of a specific type
     return list(filter(lambda obj: isinstance(obj, type), seen_objs))
+
+
+def get_task_results_shape(task):
+    """ Get the shape of the results of a task
+
+    Args:
+        task (:obj:`Task`): task
+
+    Returns:
+        :obj:`tuple` of :obj:`int`: shape of the results of a task
+    """
+    if isinstance(task, Task):
+        if isinstance(task.simulation, OneStepSimulation):
+            return (2,)
+        elif isinstance(task.simulation, SteadyStateSimulation):
+            return (1,)
+        elif isinstance(task.simulation, UniformTimeCourseSimulation):
+            return (task.simulation.number_of_steps + 1,)
+        else:
+            return (None,)
+
+    elif isinstance(task, RepeatedTask):
+        shape = [get_range_len(task.range) if task.range else None, len(task.sub_tasks)]
+        max_sub_task_shape = []
+
+        for sub_task in task.sub_tasks:
+            sub_task_shape = list(get_task_results_shape(sub_task.task))
+            max_sub_task_shape = max_sub_task_shape + [0] * max(0, len(sub_task_shape) - len(max_sub_task_shape))
+            sub_task_shape = sub_task_shape + [0] * max(0, len(max_sub_task_shape) - len(sub_task_shape))
+            max_sub_task_shape = [max(i, j) for i, j in zip(max_sub_task_shape, sub_task_shape)]
+
+        return tuple(shape + max_sub_task_shape)
+
+    return None
